==> haskell-hls-code-range-plugin-1.1.0.0-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-code-range-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-code-range-plugin-1.1.0.0-8Jrb8oXvbcwGAnM776ytr6
key:                  hls-code-range-plugin-1.1.0.0-8Jrb8oXvbcwGAnM776ytr6
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c0e686e967d9608f6bdb4793985ce481
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-code-range-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-code-range-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-1.1.0.0-8Jrb8oXvbcwGAnM776ytr6
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ mtl-2.2.2
    semigroupoids-5.3.7-9fcg6MaQJ0fQJ8sm8LFam text-1.2.5.0
    transformers-0.5.6.2 vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-code-range-plugin-1.1.0.0-204-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-code-range-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-code-range-plugin-1.1.0.0-CwyZfpKklTnDE4MxD0ZIGH
key:                  hls-code-range-plugin-1.1.0.0-CwyZfpKklTnDE4MxD0ZIGH
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7b097f2fe48eed9a0e2c8adba55d64c0
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-code-range-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-code-range-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-1.1.0.0-CwyZfpKklTnDE4MxD0ZIGH
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.15-9PmwGQvWkElDwGNWrixqMB
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO mtl-2.2.2
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg text-1.2.5.0
    transformers-0.5.6.2 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
